@@ -25,7 +25,7 @@ from conda_build.conda_interface import PY3
 from conda_build.conda_interface import TemporaryDirectory
 
 from conda_build import utils
-from conda_build.os_utils.pyldd import is_codefile, inspect_linkages
+from conda_build.os_utils.pyldd import codefile_type, inspect_linkages, get_runpaths
 from conda_build.inspect_pkg import which_package
 
 if sys.platform == 'darwin':
@@ -37,13 +37,9 @@ else:
     from scandir import scandir
 
 
-def is_obj(path):
-    return is_codefile(path)
-
-
 def fix_shebang(f, prefix, build_python, osx_is_app=False):
     path = os.path.join(prefix, f)
-    if is_obj(path):
+    if codefile_type(path):
         return
     elif os.path.islink(path):
         return
@@ -198,6 +194,13 @@ def rm_pyc(files, prefix):
             os.unlink(os.path.join(prefix, fn))
 
 
+def rm_share_info_dir(files, prefix):
+    if 'share/info/dir' in files:
+        fn = os.path.join(prefix, 'share', 'info', 'dir')
+        if os.path.isfile(fn):
+            os.unlink(fn)
+
+
 def compile_missing_pyc(files, cwd, python_exe, skip_compile_pyc=()):
     if not os.path.isfile(python_exe):
         return
@@ -241,6 +244,7 @@ def post_process(files, prefix, config, preserve_egg_dir=False, noarch=False, sk
                             skip_compile_pyc=skip_compile_pyc)
     remove_easy_install_pth(files, prefix, config, preserve_egg_dir=preserve_egg_dir)
     rm_py_along_so(prefix)
+    rm_share_info_dir(files, prefix)
 
 
 def find_lib(link, prefix, files, path=None):
@@ -288,7 +292,7 @@ def osx_ch_link(path, link_dict, host_prefix, build_prefix, files):
         link = link.replace(build_prefix, host_prefix)
         print(".. seems to be linking to a compiler runtime, replacing build prefix with "
               "host prefix and")
-        if not is_obj(link):
+        if not codefile_type(link):
             sys.exit("Error: Compiler runtime library in build prefix not found in host prefix %s"
                      % link)
         else:
@@ -333,7 +337,7 @@ def osx_ch_link(path, link_dict, host_prefix, build_prefix, files):
 
 
 def mk_relative_osx(path, host_prefix, build_prefix, files):
-    assert sys.platform == 'darwin' and is_obj(path)
+    assert sys.platform == 'darwin'
 
     names = macho.otool(path)
     s = macho.install_name_change(path,
@@ -474,13 +478,18 @@ def check_overlinking(m, files):
     whitelist += m.meta.get('build', {}).get('missing_dso_whitelist', [])
     for f in files:
         path = os.path.join(m.config.host_prefix, f)
-        if not is_obj(path):
+        if not codefile_type(path):
             continue
         warn_prelude = "WARNING ({},{})".format(pkg_name, f)
         err_prelude = "  ERROR ({},{})".format(pkg_name, f)
         info_prelude = "   INFO ({},{})".format(pkg_name, f)
         msg_prelude = err_prelude if m.config.error_overlinking else warn_prelude
 
+        runpaths = get_runpaths(path)
+        if len(runpaths):
+            print_msg(errors, '{}: runpaths {} found in {}'.format(msg_prelude,
+                                                                   runpaths,
+                                                                   path))
         needed = inspect_linkages(path, resolve_filenames=True, recurse=False)
         for needed_dso in needed:
             if needed_dso.startswith(m.config.host_prefix):
@@ -572,11 +581,12 @@ def check_overlinking(m, files):
 
 def post_process_shared_lib(m, f, files):
     path = os.path.join(m.config.host_prefix, f)
-    if not is_obj(path):
+    codefile_t = codefile_type(path)
+    if not codefile_t:
         return
-    if sys.platform.startswith('linux'):
+    if sys.platform.startswith('linux') and codefile_t == 'elffile':
         mk_relative_linux(f, m.config.host_prefix, rpaths=m.get_value('build/rpaths', ['lib']))
-    elif sys.platform == 'darwin':
+    elif sys.platform == 'darwin' and codefile_t == 'machofile':
         mk_relative_osx(path, m.config.host_prefix, m.config.build_prefix, files=files)
 
 
@@ -645,7 +655,7 @@ def check_symlinks(files, prefix, croot):
             #    because ld.so follows symlinks in RPATHS
             #    If condition exists, then copy the file rather than symlink it.
             if (not os.path.dirname(link_path) == os.path.dirname(real_link_path) and
-                    is_obj(f)):
+                    codefile_type(f)):
                 os.remove(path)
                 utils.copy_into(real_link_path, path)
             elif real_link_path.startswith(real_build_prefix):
